@@ -1,13 +1,13 @@
 /* 
    drvrpl.cpp - Driver to output Real3D RPL polygons
-             - written by Glenn M. Lewis <glenn@gmlewis.com> - 6/18/96
+             - written by Glenn M. Lewis <glenn_AT_gmlewis.com> - 6/18/96
 	       http://www.gmlewis.com/>
 	       Based on...
 
    drvSAMPL.cpp : This file is part of pstoedit
    Skeleton for the implementation of new backends
 
-   Copyright (C) 1993 - 2003 Wolfgang Glunz, wglunz@pstoedit.net
+   Copyright (C) 1993 - 2005 Wolfgang Glunz, wglunz34_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -92,9 +92,9 @@ void drvRPL::close_page()
 void drvRPL::show_path()
 {
 	print_coords();
-};
+}
 
-static DriverDescriptionT < drvRPL > D_rpl("rpl", "Real3D Programming Language Format", "rpl", false,	// if backend supports subpathes, else 0
+static DriverDescriptionT < drvRPL > D_rpl("rpl", "Real3D Programming Language Format","", "rpl", false,	// if backend supports subpathes, else 0
 										   // if subpathes are supported, the backend must deal with
 										   // sequences of the following form
 										   // moveto (start of subpath)
@@ -112,6 +112,5 @@ static DriverDescriptionT < drvRPL > D_rpl("rpl", "Real3D Programming Language F
 										   false,	// if backend supports text, else 0
 										   DriverDescription::noimage,	// no support for PNG file images
 										   DriverDescription::normalopen, false,	// if format supports multiple pages in one file
-										   false, /*clipping */ 
-										   nodriverspecificoptions);
- 
+										   false  /*clipping */ 
+										   );
